from os.path import join, split
from os import makedirs, getcwd
from Flask_DJ.exceptions import CreationError


def create_file(path, name, template):
    with open(join(path, f'{name}.py'), 'w') as f:
        f.write(template)


def create_folder(path):
    try:
        makedirs(path)
    except FileExistsError:
        raise CreationError('The directory with that name already exists.')
    except PermissionError:
        raise CreationError('You do not have enough permissions to act in this directory, '
                            'try changing users and try again.')


def get_project_name():
    return split(getcwd())[-1]



__title__ = 'Flask-DJ'
__description__ = 'Django (mvc) structure for your Flask project.'
__url__ = 'https://github.com/AlexandrovRoman/Flask-DJ'
__version__ = '0.1.6'
__author__ = 'Alexandrov Roman'
__author_email__ = 'flask-dj.feedback@yandex.com'
__license__ = 'MIT License'
__keywords__ = 'mvc django flask structure'



from setuptools import setup, find_packages
from Flask_DJ import __version__, __title__, __description__, __author_email__, __author__, __keywords__, __license__
from os import path

here = path.abspath(path.dirname(__file__))

# Get the long description from the README file
with open(path.join(here, 'README.md'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name=__title__,  # Required
    version=__version__,  # Required
    description=__description__,  # Optional
    long_description=long_description,  # Optional
    long_description_content_type='text/markdown',  # Optional (see note above)
    url='https://github.com/AlexandrovRoman/Flask-DJ',  # Optional
    author=__author__,  # Optional
    author_email=__author_email__,  # Optional
    classifiers=[  # Optional
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        f'License :: OSI Approved :: {__license__}',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
    ],
    keywords=__keywords__,  # Optional
    packages=find_packages(),  # Required
    install_requires=[
        'waitress==1.4.3',
        'flask==1.1.1',
        'Flask-Migrate==2.5.2',
        'Flask-Script==2.0.6',
        'Flask-SQLAlchemy==2.4.1',
        'WTForms==2.2.1',
        'SQLAlchemy==1.3.13',
        'Flask-WTF==0.14.3',
        'Flask-Login==0.5.0'
    ],
    entry_points={
        'console_scripts': [
            'flask-dj = Flask_DJ:command',
        ],
    },
    project_urls={
        "Source": "https://github.com/AlexandrovRoman/Flask-DJ",
        "Docs": "https://flask-dj.readthedocs.io/en/latest/"
    }
)
